"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const errors_1 = require("../utlis/errors");
const db_1 = require("../utlis/db");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100) {
            throw new errors_1.ValidationError('Ad name cannot be empty and cannot exceed 100 characters');
        }
        if (obj.desc.length > 1000) {
            throw new errors_1.ValidationError('Ad description cannot exceed 1000 characters');
        }
        if (obj.price < 0 || obj.price > 9999999) {
            throw new errors_1.ValidationError('Price cannot be negative or greater than 9 999 999');
        }
        //@TODO: check if url is valid!
        if (!obj.url || obj.url.length > 100) {
            throw new errors_1.ValidationError('Ad url cannot be empty and cannot exceed 100 characters');
        }
        if (typeof (obj === null || obj === void 0 ? void 0 : obj.lat) !== 'number' || typeof (obj === null || obj === void 0 ? void 0 : obj.lon) !== 'number') {
            throw new errors_1.ValidationError('Cannot locate ad');
        }
        obj.id ? this.id = obj.id : null;
        this.name = obj.name;
        this.desc = obj.desc;
        this.price = obj.price;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lon = obj.lon;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `id` = :id", {
                id,
            });
            return results.length === 0 ? null : new AdRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already in database');
            }
            yield db_1.pool.execute("INSERT INTO `ads` VALUES (:id, :name, :desc, :price, :url, :lat, :lon)", this);
            return this.id;
        });
    }
    static find(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `ads` WHERE `name` LIKE :search", {
                search: `%${name}%`,
            });
            return results.map(result => {
                const { id, lat, lon, } = result;
                return {
                    id, lat, lon,
                };
            });
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map