import {AdRecord} from "../records/ad.record";
import {pool} from "../utlis/db";
import {AdEntity} from "../types";
import {testAd} from "./testRecord";

afterAll(async () => {
  await pool.execute("DELETE FROM `ads` WHERE `name` = 'Test name'");
  await pool.end();
});

test('AdRecord returns data from database for one entry', async () => {
  const ad = await AdRecord.getOne('testId');

  expect(ad).toBeDefined();
  expect(ad?.id).toBe('testId');
  expect(ad?.name).toBe('testowa reklama');
  expect(ad?.desc).toBe('testowy opis ');
});

test('AdRecord returns null from database for not existing entry', async () => {
  const ad = await AdRecord.getOne('loremIpsum');
  expect(ad).toBeNull();
});

test('AdRecord.insert returns new UUID', async () => {
  const ad = new AdRecord({
    ...testAd,
  });
  await ad.insert();

  expect(ad.id).toBeDefined();
});

test('AdRecord.insert inserts data to database', async () => {
  const ad = new AdRecord({
    ...testAd,
  });

  await ad.insert();

  const foundAd = await AdRecord.getOne(ad.id);
  expect(foundAd).toBeDefined();
  expect(foundAd).not.toBeNull();
  expect(foundAd && foundAd.id).toBe(ad.id);
});

test('AdRecord.find returns array of found entries when searching for "a"', async () => {
  const ads = await AdRecord.find('a');

  expect(ads).not.toHaveLength(0);
  expect(ads[0].id).toBeDefined();

});

test('AdRecord.find returns empty array when searching for something that does not exist', async () => {
  const ads = await AdRecord.find('-------------');

  expect(ads).toHaveLength(0);

})

test('AdRecord.find returns only desired amount of data', async () => {
  const ads = await AdRecord.find('');

  expect((ads[0] as AdEntity).desc).toBeUndefined();
  expect((ads[0] as AdEntity).price).toBeUndefined();

})
