"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.authMiddleware = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const records_1 = require("../records");
const JWT_SECRET = process.env.JWT_SECRET || 'default_secret';
const authMiddleware = (requiredRole) => (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const token = (_a = req.headers.authorization) === null || _a === void 0 ? void 0 : _a.split(' ')[1];
    if (!token) {
        return res.status(401).json({
            status: req.statusCode,
            message: 'No token provided',
        });
    }
    try {
        const decodedToken = jsonwebtoken_1.default.verify(token, JWT_SECRET);
        // if user is not authorized to access the requested dashboard
        if (requiredRole === 'user' && decodedToken.userId !== req.params.userId) {
            return res.status(401).json({
                status: res.statusCode,
                message: 'You are not authorized to access this page',
            });
        }
        // if role of the user in the decoded token is different from the requiredRole
        if (decodedToken.role !== requiredRole) {
            return res.status(403).json({
                status: res.statusCode,
                message: 'Forbidden: Access is denied',
            });
        }
        const user = yield records_1.UserRecord.findById(decodedToken.userId);
        // if user wants access to admin panel
        if (user && user.role !== requiredRole) {
            return res.status(403).json({
                status: res.statusCode,
                message: 'Forbidden: Access is denied',
            });
        }
        next();
    }
    catch (error) {
        console.error(error);
        // if not logged person wants access to admin panel or token expired
        if (error instanceof jsonwebtoken_1.default.TokenExpiredError) {
            res.status(401).json({
                status: res.statusCode,
                message: 'Token has expired'
            });
        }
        else {
            res.status(401).json({
                status: res.statusCode,
                message: 'You are not authorized to access this page'
            });
        }
    }
});
exports.authMiddleware = authMiddleware;
//# sourceMappingURL=auth.middleware.js.map