"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OrderRecord = void 0;
const utlis_1 = require("../utlis");
const uuid_1 = require("uuid");
class OrderRecord {
    constructor(obj) {
        if (obj.totalQty === 0) {
            throw new utlis_1.ValidationError('Order cannot be empty');
        }
        if (obj.totalValue < 0) {
            throw new utlis_1.ValidationError('Total order value cannot be negative');
        }
        if (obj.totalValue === 0) {
            throw new utlis_1.ValidationError('Total order value must be greater than zero');
        }
        this.products = obj.products;
        this.totalValue = obj.totalValue;
        this.totalQty = obj.totalQty;
        this.userId = obj.userId;
        obj.orderNo ? (this.orderNo = obj.orderNo) : null;
        obj.orderId ? (this.orderId = obj.orderId) : null;
        obj.createdAt ? (this.createdAt = obj.createdAt) : null;
        obj.createdAt ? (this.createdAt = obj.createdAt) : null;
        obj.status ? (this.status = obj.status) : null;
    }
    static getOrder(orderId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `orders` WHERE `orderId` = :orderId', {
                orderId,
            }));
            return results.length === 0 ? null : new OrderRecord(results[0]);
        });
    }
    static getOrderedProducts(orderId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `order_details` WHERE `orderId` = :orderId', {
                orderId,
            }));
            if (results.length === 0) {
                return null;
            }
            return results.map((result) => {
                const { productId, orderedQty } = result;
                return {
                    productId,
                    orderedQty,
                };
            });
        });
    }
    static getUserOrders(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `orders` WHERE `userId` = :userId ORDER BY createdAt DESC', {
                userId,
            }));
            return results.length === 0 ? null : results;
        });
    }
    static getAllOrders() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `orders` ORDER BY createdAt DESC'));
            return results.length === 0 ? null : results;
        });
    }
    saveOrder() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.orderId) {
                this.orderId = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already in database');
            }
            this.status = 'pending';
            yield utlis_1.pool.execute('INSERT INTO `orders` (`orderId`, `userId`, `totalValue`, `totalQty`, `status`) VALUES (:orderId, :userId, :totalValue, :totalQty, :status)', {
                orderId: this.orderId,
                userId: this.userId,
                totalValue: this.totalValue,
                totalQty: this.totalQty,
                status: this.status,
            });
            this.products.forEach((one) => {
                (() => __awaiter(this, void 0, void 0, function* () {
                    yield utlis_1.pool.execute('INSERT INTO `order_details` VALUES (:orderId, :productId, :orderedQty)', {
                        orderId: this.orderId,
                        productId: one.productId,
                        orderedQty: one.orderedQty,
                    });
                }))();
            });
        });
    }
    static getOrderNumber(orderId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT `orderNo` FROM `orders` WHERE `orderId` = :orderId', {
                orderId,
            }));
            return results.length === 0 ? null : results[0].orderNo;
        });
    }
}
exports.OrderRecord = OrderRecord;
//# sourceMappingURL=order.record.js.map