"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProductRecord = void 0;
const uuid_1 = require("uuid");
const utlis_1 = require("../utlis");
class ProductRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100) {
            throw new utlis_1.ValidationError('Product name cannot be empty and cannot exceed 100 characters');
        }
        if (obj.description.length > 1000) {
            throw new utlis_1.ValidationError('Product description cannot exceed 1000 characters');
        }
        if (obj.lifeInDays < 0 || obj.lifeInDays > 366) {
            throw new utlis_1.ValidationError('Product life cannot be negative or exceed one year');
        }
        if (obj.price < 0 || obj.price > 99.99) {
            throw new utlis_1.ValidationError('Price cannot be negative or greater than 99.99');
        }
        if (obj.energy < 0 || obj.energy > 500) {
            throw new utlis_1.ValidationError('Energy cannot be negative or greater than 500 kcal');
        }
        if (obj.fat < 0 ||
            obj.fat > 99.99 ||
            obj.protein < 0 ||
            obj.protein > 99.99 ||
            obj.fibre < 0 ||
            obj.fibre > 99.99 ||
            obj.sugars < 0 ||
            obj.sugars > 99.99 ||
            obj.salt < 0 ||
            obj.salt > 99.99) {
            throw new utlis_1.ValidationError('Nutrition data cannot be negative or greater than 99.99g');
        }
        obj.productId ? (this.productId = obj.productId) : null;
        this.name = obj.name;
        this.price = obj.price;
        this.description = obj.description;
        this.lifeInDays = obj.lifeInDays;
        this.energy = obj.energy;
        this.fat = obj.fat;
        this.protein = obj.protein;
        this.fibre = obj.fibre;
        this.sugars = obj.sugars;
        this.salt = obj.salt;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `products` WHERE `productId` = :id', {
                id,
            }));
            return results.length === 0 ? null : new ProductRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.productId) {
                this.productId = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already in database');
            }
            yield utlis_1.pool.execute('INSERT INTO `products` VALUES (:productId, :name, :description, :lifeInDays, :price, :energy, :fat, :protein, :fibre, :sugars, :salt)', this);
            return this.productId;
        });
    }
    static find(name) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT * FROM `products` WHERE `name` LIKE :search', {
                search: `%${name}%`,
            }));
            return results.map((result) => {
                const { productId, name, price } = result;
                return {
                    productId,
                    name,
                    price,
                };
            });
        });
    }
    static getBestsellers() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute('SELECT p.productId, p.name, p.price, COUNT(*) AS order_count, SUM(order_details.orderedQty) AS total_ordered_qty\n' +
                'FROM products p\n' +
                'JOIN order_details ON p.productId = order_details.productId\n' +
                'GROUP BY p.productId\n' +
                'ORDER BY order_count DESC, total_ordered_qty DESC\n' +
                'LIMIT 3;'));
            return results.map((result) => {
                const { productId, name, price } = result;
                return {
                    productId,
                    name,
                    price,
                };
            });
        });
    }
}
exports.ProductRecord = ProductRecord;
//# sourceMappingURL=product.record.js.map