"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRecord = void 0;
const uuid_1 = require("uuid");
const utlis_1 = require("../utlis");
class UserRecord {
    constructor(obj) {
        this.email = obj.email;
        this.password = obj.password;
        this.role = obj.role;
        obj.userId ? (this.userId = obj.userId) : null;
        obj.createdAt ? (this.createdAt = obj.createdAt) : null;
        obj.updatedAt ? (this.updatedAt = obj.updatedAt) : null;
    }
    static getAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute(` SELECT users.*, roles.name AS role 
            FROM users
            JOIN user_roles ur ON users.userId = ur.userId 
            JOIN roles roles ON ur.roleId = roles.roleId 
            ORDER BY users.email ASC`));
            return results.map((result) => {
                const { userId, email, role } = result;
                return {
                    userId,
                    email,
                    role,
                };
            });
        });
    }
    static findByEmail(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute(` SELECT users.*, roles.name AS role 
            FROM users 
            JOIN user_roles ON users.userId = user_roles.userId 
            JOIN roles ON user_roles.roleId = roles.roleId
            WHERE users.email = :email`, {
                email,
            }));
            return results.length === 0 ? null : new UserRecord(results[0]);
        });
    }
    static findById(userId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield utlis_1.pool.execute(` SELECT users.*, roles.name AS role 
            FROM users 
            JOIN user_roles ON users.userId = user_roles.userId 
            JOIN roles ON user_roles.roleId = roles.roleId
            WHERE users.userId = :userId`, {
                userId,
            }));
            if (results.length === 0) {
                return null;
            }
            const { role, email, updatedAt, createdAt } = results[0];
            return {
                userId,
                role,
                email,
                updatedAt,
                createdAt,
            };
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.userId) {
                this.userId = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already in database');
            }
            yield utlis_1.pool.execute('INSERT INTO `users` (`userId`, `email`, `password`) VALUES (:userId, :email, :password)', this);
            yield utlis_1.pool.execute('INSERT INTO `user_roles` (`userId`, `roleId`)  VALUES (:userId, :roleId)', {
                userId: this.userId,
                roleId: this.role === 'user' ? 'role_user' : 'role_admin',
            });
            return this.userId;
        });
    }
}
exports.UserRecord = UserRecord;
//# sourceMappingURL=user.record.js.map