"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.accountRouter = void 0;
const express_1 = require("express");
const bcrypt_1 = require("bcrypt");
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const records_1 = require("../records");
const utlis_1 = require("../utlis");
const JWT_SECRET = process.env.JWT_SECRET || 'default_secret';
exports.accountRouter = (0, express_1.Router)();
exports.accountRouter
    .post('/signup', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, password, confirmPassword } = req.body;
    if (!email || !password) {
        return res.status(400).json({
            status: res.statusCode,
            message: 'Missing required fields',
        });
    }
    if (password !== confirmPassword) {
        return res.status(400).json({
            status: res.statusCode,
            message: 'Password does not match',
        });
    }
    const isAlreadySigned = yield records_1.UserRecord.findByEmail(email);
    if (isAlreadySigned) {
        return res.status(400).json({
            status: res.statusCode,
            message: 'Email is invalid or has been taken',
        });
    }
    // validation of provided data
    (0, utlis_1.validateEmail)(email);
    (0, utlis_1.validatePassword)(password);
    // encrypt password
    const hashedPassword = yield (0, bcrypt_1.hash)(password, 10);
    // create new user
    const validUser = new records_1.UserRecord({
        email,
        password: String(hashedPassword),
        role: 'user',
    });
    yield validUser.insert();
    res.status(200).json({
        status: res.statusCode,
        message: 'Account created successfully',
    });
}))
    .post('/login', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { email, password } = req.body;
        // findByEmail user by provided email
        const user = yield records_1.UserRecord.findByEmail(email);
        // check if user exists
        if (!user) {
            return res.status(401).json({
                status: res.statusCode,
                message: 'User not found',
            });
        }
        // check if provided password is correct
        const isMatch = yield (0, bcrypt_1.compare)(password, user.password);
        if (!isMatch) {
            return res.status(401).json({
                status: res.statusCode,
                message: 'Invalid email or password',
            });
        }
        // generate token
        const token = jsonwebtoken_1.default.sign({
            role: user.role,
            userId: user.userId,
        }, JWT_SECRET, {
            expiresIn: 60 * 60 * 3, // 3 hours
        });
        res.status(200).json({
            status: res.statusCode,
            role: user.role,
            userId: user.userId,
            token,
        });
    }
    catch (err) {
        res.status(500).json({
            status: res.statusCode,
            error: err,
            message: 'Internal server error',
        });
    }
}));
//# sourceMappingURL=account.router.js.map