"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.userRouter = void 0;
const express_1 = require("express");
const auth_middleware_1 = require("../middleware/auth.middleware");
const records_1 = require("../records");
exports.userRouter = (0, express_1.Router)();
exports.userRouter
    .get('/:userId/dashboard', (0, auth_middleware_1.authMiddleware)('user'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const user = yield records_1.UserRecord.findById(req.params.userId);
    /* prettier-ignore */
    if (!user) {
        res.status(404).json({
            status: res.statusCode,
            message: "User not found"
        });
    }
    res.status(200).json(user);
}))
    .get('/:userId/orders', (0, auth_middleware_1.authMiddleware)('user'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const orders = yield records_1.OrderRecord.getUserOrders(req.params.userId);
    if (orders === null) {
        res.status(404).json({
            status: res.statusCode,
            message: 'No orders found yet',
        });
    }
    else {
        res.status(200).json(orders);
    }
}))
    .post('/:userId/order/new', (0, auth_middleware_1.authMiddleware)('user'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const userOrder = req.body;
    const newOrder = new records_1.OrderRecord(userOrder);
    yield newOrder.saveOrder();
    const orderNumber = yield records_1.OrderRecord.getOrderNumber(newOrder.orderId);
    res.status(200).json({
        status: res.statusCode,
        message: 'Order created successfully',
        orderNumber,
    });
}))
    .get('/:userId/order/:orderId', (0, auth_middleware_1.authMiddleware)('user'), (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const { userId, orderId } = req.params;
    const order = yield records_1.OrderRecord.getOrder(orderId);
    if (!order) {
        return res.status(404).json({
            status: res.statusCode,
            message: 'Order not found',
        });
    }
    // check if the order belongs to user
    const isUserOrder = (order === null || order === void 0 ? void 0 : order.userId) === userId;
    if (!isUserOrder) {
        return res.status(403).json({
            status: res.statusCode,
            message: `You are not authorized to see this page`,
        });
    }
    const products = yield records_1.OrderRecord.getOrderedProducts(orderId);
    res.status(200).json({ order, products });
}));
//# sourceMappingURL=user.router.js.map