"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utlis_1 = require("../../utlis");
const testingRecord_1 = require("./testingRecord");
const records_1 = require("../../records");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield utlis_1.pool.execute("DELETE FROM `order_details` WHERE `productId` = 'test_product1'");
    yield utlis_1.pool.execute("DELETE FROM `orders` WHERE `userId` = 'test_user'");
    yield utlis_1.pool.end();
}));
// -- testing getOrder() method
test('OrderRecord.getOrder() returns order data from database', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getOrder('first_order');
    expect(order).toBeDefined();
    expect(order === null || order === void 0 ? void 0 : order.totalValue).toBe(420);
    expect(order === null || order === void 0 ? void 0 : order.totalQty).toBe(99);
}));
test('OrderRecord.getOrder() returns null from database for not existing order', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getOrder('loremIpsum');
    expect(order).toBeNull();
}));
// --end of testing getOrder() method
// -- testing getOrderedProducts() method
test('OrderRecord.getOrderedProducts() returns ordered products from database for existing order', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getOrderedProducts('first_order');
    expect(order).toBeDefined();
    expect(order === null || order === void 0 ? void 0 : order.length).toBe(2);
}));
test('OrderRecord.getOrderedProducts()  returns null from database for not existing order', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getOrderedProducts('loremIpsum');
    expect(order).toBeNull();
}));
// --end of testing getOrderedProducts() method
// -- testing getUserOrders() method
test('OrderRecord.getUserOrders() returns order data from database', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getUserOrders('25cc95b3-c83f-4262-af4a-52b9e0a761f6');
    expect(order).toBeDefined();
    expect(order === null || order === void 0 ? void 0 : order.length).toBe(2);
    expect(order && order[1].orderId).toBe('second_order');
}));
test('OrderRecord.getUserOrders() returns null from database for not existing user', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = yield records_1.OrderRecord.getUserOrders('loremIpsum');
    expect(order).toBeNull();
}));
// --end of testing getUserOrders() method
// -- testing getAllOrders() method
test('OrderRecord returns all orders', () => __awaiter(void 0, void 0, void 0, function* () {
    const orders = yield records_1.OrderRecord.getAllOrders();
    expect(orders).toBeDefined();
    expect(orders).not.toBeNull();
}));
// --end of testing getAllOrders() method
// -- testing saveOrder() method
test('UserRecord.saveOrder inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const order = new records_1.OrderRecord(Object.assign({}, testingRecord_1.testOrder));
    yield order.saveOrder();
    const newOrder = yield records_1.OrderRecord.getOrder(order.orderId);
    expect(newOrder).toBeDefined();
    expect(newOrder).not.toBeNull();
    expect(newOrder === null || newOrder === void 0 ? void 0 : newOrder.orderId).toBe(order.orderId);
}));
// -- end of testing saveOrder() method
// -- testing getOrderNumber() method
test('OrderRecord returns all orders', () => __awaiter(void 0, void 0, void 0, function* () {
    const orders = yield records_1.OrderRecord.getOrderNumber('first_order');
    expect(orders).toBeDefined();
    expect(orders).not.toBeNull();
    expect(orders).toBe(1);
}));
// --end of testing getOrderNumber() method
//# sourceMappingURL=order.test.js.map