"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testingRecord_1 = require("./testingRecord");
const records_1 = require("../../records");
let errMessage;
test('Can build ProductsRecord', () => {
    expect(testingRecord_1.testProduct.name).toBe('Test name');
    expect(testingRecord_1.testProduct.description).toBe('Test description');
    expect(testingRecord_1.testProduct.price).toStrictEqual(99.99);
    expect(testingRecord_1.testProduct.energy).toStrictEqual(100);
    expect(testingRecord_1.testProduct.lifeInDays).toStrictEqual(360);
    expect(testingRecord_1.testProduct.fat &&
        testingRecord_1.testProduct.protein &&
        testingRecord_1.testProduct.fibre &&
        testingRecord_1.testProduct.sugars &&
        testingRecord_1.testProduct.salt).toStrictEqual(20.5);
});
test('Throws when invalid name provided', () => {
    errMessage = 'Product name cannot be empty and cannot exceed 100 characters';
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { name: '' }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { name: 'Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test Test' }))).toThrow(errMessage);
});
test('Throws when too long description provided', () => {
    errMessage = 'Product description cannot exceed 1000 characters';
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { description: testingRecord_1.stringOver1000 }))).toThrow(errMessage);
});
test('Throws when invalid price provided', () => {
    errMessage = 'Price cannot be negative or greater than 99.99';
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { price: -10 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { price: 100 }))).toThrow(errMessage);
});
test('Throws when invalid energy amount provided', () => {
    errMessage = 'Energy cannot be negative or greater than 500 kcal';
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { energy: -501 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { energy: 501 }))).toThrow(errMessage);
});
test('Throws when invalid nutrition data provided', () => {
    errMessage = 'Nutrition data cannot be negative or greater than 99.99g';
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { fat: -1 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { protein: -1 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { fibre: -1 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { sugars: -1 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { salt: -1 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { fat: 100 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { protein: 100 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { fibre: 100 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { sugars: 100 }))).toThrow(errMessage);
    expect(() => new records_1.ProductRecord(Object.assign(Object.assign({}, testingRecord_1.testProduct), { salt: 100 }))).toThrow(errMessage);
});
//# sourceMappingURL=product-record.test.js.map