"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utlis_1 = require("../../utlis");
const testingRecord_1 = require("./testingRecord");
const records_1 = require("../../records");
afterAll(() => __awaiter(void 0, void 0, void 0, function* () {
    yield utlis_1.pool.execute("DELETE FROM `products` WHERE `name` = 'Test name'");
    yield utlis_1.pool.end();
}));
// -- testing insert(productId) method
test('ProductRecord.insert inserts data to database', () => __awaiter(void 0, void 0, void 0, function* () {
    const product = new records_1.ProductRecord(Object.assign({}, testingRecord_1.testProduct));
    yield product.insert();
    const newProduct = yield records_1.ProductRecord.getOne(product.productId);
    expect(newProduct).toBeDefined();
    expect(newProduct).not.toBeNull();
    expect(newProduct === null || newProduct === void 0 ? void 0 : newProduct.productId).toBe(product.productId);
}));
// -- end of testing insert(productId) method
// -- testing getOne() method
test('ProductRecord returns data from database for one entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const product = yield records_1.ProductRecord.getOne('8aad8b13-ef02-4730-8456-3cd89c1f146d');
    expect(product).toBeDefined();
    expect(product === null || product === void 0 ? void 0 : product.productId).toBe('8aad8b13-ef02-4730-8456-3cd89c1f146d');
    expect(product === null || product === void 0 ? void 0 : product.name).toBe('tomatoes');
    expect(product === null || product === void 0 ? void 0 : product.description).toBe('Sweet and juicy vine-ripened Class I Rosa tomatoes. Wash before use. Source of Vitamin C. 1 of your 5 a day.Product life guaranteed for 3 days excluding delivery day, with an average of 4 days.');
    expect(product === null || product === void 0 ? void 0 : product.lifeInDays).toStrictEqual(5);
    expect(product === null || product === void 0 ? void 0 : product.price).toStrictEqual(3.49);
    expect(product === null || product === void 0 ? void 0 : product.energy).toStrictEqual(14);
    expect(product === null || product === void 0 ? void 0 : product.fat).toStrictEqual(0.1);
    expect(product === null || product === void 0 ? void 0 : product.protein).toStrictEqual(0.5);
    expect(product === null || product === void 0 ? void 0 : product.fibre).toStrictEqual(1.0);
    expect(product === null || product === void 0 ? void 0 : product.sugars).toStrictEqual(3.0);
    expect(product === null || product === void 0 ? void 0 : product.salt).toStrictEqual(0.1);
}));
test('ProductRecord returns null from database for not existing entry', () => __awaiter(void 0, void 0, void 0, function* () {
    const product = yield records_1.ProductRecord.getOne('loremIpsum');
    expect(product).toBeNull();
}));
// --end of testing getOne() method
// -- testing find() method
test('ProductRecord.find returns only desired amount of data', () => __awaiter(void 0, void 0, void 0, function* () {
    const products = yield records_1.ProductRecord.find('');
    expect(products[0].description).toBeUndefined();
    expect(products[0].energy).toBeUndefined();
    expect(products[0].fat).toBeUndefined();
    expect(products[0].protein).toBeUndefined();
    expect(products[0].fibre).toBeUndefined();
    expect(products[0].sugars).toBeUndefined();
    expect(products[0].salt).toBeUndefined();
}));
test('ProductRecord.find returns empty array when searching for something that does not exist', () => __awaiter(void 0, void 0, void 0, function* () {
    const products = yield records_1.ProductRecord.find('----');
    expect(products).toHaveLength(0);
}));
test('ProductRecord.find returns array of found entries when searching for "a"', () => __awaiter(void 0, void 0, void 0, function* () {
    const products = yield records_1.ProductRecord.find('a');
    expect(products).not.toHaveLength(0);
    expect(products[0].productId).toBeDefined();
}));
// -- end of testing find() method
// -- testing getBestsellers() method
test('ProductRecord.getBestsellers returns exactly 3 records', () => __awaiter(void 0, void 0, void 0, function* () {
    const products = yield records_1.ProductRecord.getBestsellers();
    expect(products.length).toStrictEqual(3);
}));
// -- end of testing getBestsellers() method
//# sourceMappingURL=products.test.js.map