"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utlis_1 = require("../../utlis");
let errMessage;
describe('Validate password', () => {
    it('Throws if password is not provided', () => {
        errMessage = 'Password must be provided';
        expect(() => {
            (0, utlis_1.validatePassword)('');
        }).toThrow(errMessage);
    });
    it('Throws when too short password provided', () => {
        errMessage = 'Password must be at least 8 and no more than 20 characters long';
        expect(() => {
            (0, utlis_1.validatePassword)('1234567');
        }).toThrow(errMessage);
    });
    it('Throws when too long password provided', () => {
        expect(() => {
            (0, utlis_1.validatePassword)('123456789012345678901');
        }).toThrow(errMessage);
    });
    it('Throws if password does not contain at least one number', () => {
        errMessage = 'Password is not strong enough';
        expect(() => {
            (0, utlis_1.validatePassword)('abcdefghi');
        }).toThrow(errMessage);
    });
    it('Throws if password does not contain at least one small letter', () => {
        expect(() => {
            (0, utlis_1.validatePassword)('ABCDEFGH1');
        }).toThrow(errMessage);
    });
    it('Throws if password does not contain at least one capital letter', () => {
        expect(() => {
            (0, utlis_1.validatePassword)('abcdefgh1');
        }).toThrow(errMessage);
    });
    it('Throws if password does not contain at least one special character', () => {
        expect(() => {
            (0, utlis_1.validatePassword)('abcdefgh1A');
        }).toThrow(errMessage);
    });
    it('Throws if password contains 2 same characters next to each other', () => {
        expect(() => {
            (0, utlis_1.validatePassword)('AbCd3f3#11');
        }).toThrow(errMessage);
    });
});
//# sourceMappingURL=validatePassword.test.js.map